@@ -16,7 +16,4 @@
 # under the License.
 
 __project_name__ = "Airphin"
-__version__ = "0.0.3"
-__description__ = (
-    "Airphin is a tool for converting Airflow DAGs to DolphinScheduler Python API."
-)
+__version__ = "0.0.6"
